<a id="mypy-boto3-shield"></a>

# mypy-boto3-shield

[![PyPI - types-aiobotocore-shield](https://img.shields.io/pypi/v/types-aiobotocore-shield.svg?color=blue)](https://pypi.org/project/types-aiobotocore-shield)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-shield.svg?color=blue)](https://pypi.org/project/types-aiobotocore-shield)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-shield?color=blue)](https://pypistats.org/packages/types-aiobotocore-shield)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.Shield 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-shield docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_shield/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-shield](#mypy-boto3-shield)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Shield`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Shield` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[shield]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[shield]'

# standalone installation
python -m pip install types-aiobotocore-shield
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[shield]` in your environment:
  `python -m pip install 'types-aiobotocore[shield]'`

Both type checking and auto-complete should work for `Shield` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[shield]` in your environment:
  `python -m pip install 'types-aiobotocore[shield]'`

Both type checking and auto-complete should work for `Shield` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[shield]` in your environment:
  `python -m pip install 'types-aiobotocore[shield]'`
- Run `mypy` as usual

Type checking should work for `Shield` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[shield]` in your environment:
  `python -m pip install 'types-aiobotocore[shield]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Shield` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ShieldClient` provides annotations for `session.create_client("shield")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_shield import ShieldClient

session = get_session()
async with session.create_client("shield") as client:
    client: ShieldClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_shield.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_shield import ShieldClient
from types_aiobotocore_shield.paginator import (
    ListAttacksPaginator,
    ListProtectionsPaginator,
)

session = get_session()
async with session.create_client("shield") as client:
    client: ShieldClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_attacks_paginator: ListAttacksPaginator = client.get_paginator("list_attacks")
        list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
    ```







### Literals

`types_aiobotocore_shield.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_shield.literals import (
    ApplicationLayerAutomaticResponseStatusType,
    AttackLayerType,
    AttackPropertyIdentifierType,
    AutoRenewType,
    ListAttacksPaginatorName,
    ListProtectionsPaginatorName,
    ProactiveEngagementStatusType,
    ProtectedResourceTypeType,
    ProtectionGroupAggregationType,
    ProtectionGroupPatternType,
    SubResourceTypeType,
    SubscriptionStateType,
    UnitType,
    ServiceName,
    PaginatorName,
)

def check_value(value: ApplicationLayerAutomaticResponseStatusType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_shield.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_shield.type_defs import (
    ApplicationLayerAutomaticResponseConfigurationTypeDef,
    AssociateDRTLogBucketRequestRequestTypeDef,
    AssociateDRTRoleRequestRequestTypeDef,
    AssociateHealthCheckRequestRequestTypeDef,
    AssociateProactiveEngagementDetailsRequestRequestTypeDef,
    AttackDetailTypeDef,
    AttackPropertyTypeDef,
    AttackStatisticsDataItemTypeDef,
    AttackSummaryTypeDef,
    AttackVectorDescriptionTypeDef,
    AttackVolumeStatisticsTypeDef,
    AttackVolumeTypeDef,
    ContributorTypeDef,
    CreateProtectionGroupRequestRequestTypeDef,
    CreateProtectionRequestRequestTypeDef,
    CreateProtectionResponseTypeDef,
    DeleteProtectionGroupRequestRequestTypeDef,
    DeleteProtectionRequestRequestTypeDef,
    DescribeAttackRequestRequestTypeDef,
    DescribeAttackResponseTypeDef,
    DescribeAttackStatisticsResponseTypeDef,
    DescribeDRTAccessResponseTypeDef,
    DescribeEmergencyContactSettingsResponseTypeDef,
    DescribeProtectionGroupRequestRequestTypeDef,
    DescribeProtectionGroupResponseTypeDef,
    DescribeProtectionRequestRequestTypeDef,
    DescribeProtectionResponseTypeDef,
    DescribeSubscriptionResponseTypeDef,
    DisableApplicationLayerAutomaticResponseRequestRequestTypeDef,
    DisassociateDRTLogBucketRequestRequestTypeDef,
    DisassociateHealthCheckRequestRequestTypeDef,
    EmergencyContactTypeDef,
    EnableApplicationLayerAutomaticResponseRequestRequestTypeDef,
    GetSubscriptionStateResponseTypeDef,
    LimitTypeDef,
    ListAttacksRequestRequestTypeDef,
    ListAttacksResponseTypeDef,
    ListProtectionGroupsRequestRequestTypeDef,
    ListProtectionGroupsResponseTypeDef,
    ListProtectionsRequestRequestTypeDef,
    ListProtectionsResponseTypeDef,
    ListResourcesInProtectionGroupRequestRequestTypeDef,
    ListResourcesInProtectionGroupResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    MitigationTypeDef,
    PaginatorConfigTypeDef,
    ProtectionGroupArbitraryPatternLimitsTypeDef,
    ProtectionGroupLimitsTypeDef,
    ProtectionGroupPatternTypeLimitsTypeDef,
    ProtectionGroupTypeDef,
    ProtectionLimitsTypeDef,
    ProtectionTypeDef,
    ResponseActionTypeDef,
    ResponseMetadataTypeDef,
    SubResourceSummaryTypeDef,
    SubscriptionLimitsTypeDef,
    SubscriptionTypeDef,
    SummarizedAttackVectorTypeDef,
    SummarizedCounterTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TimeRangeTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateApplicationLayerAutomaticResponseRequestRequestTypeDef,
    UpdateEmergencyContactSettingsRequestRequestTypeDef,
    UpdateProtectionGroupRequestRequestTypeDef,
    UpdateSubscriptionRequestRequestTypeDef,
)

def get_structure() -> ApplicationLayerAutomaticResponseConfigurationTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-shield` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-shield docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_shield/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
